@@ -1,19 +1,9 @@
-/***************************************************************************
-                     export a KEduVocDocument to a KVTML file
-    -----------------------------------------------------------------------
-    copyright       : (C) 2007 Jeremy Whiting <jpwhiting@kde.org>
-                      (C) 2007-2008 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
-
+/*
+ * export a KEduVocDocument to a KVTML file
+ * SPDX-FileCopyrightText: 2007 Jeremy Whiting <jpwhiting@kde.org>
+ * SPDX-FileCopyrightText: 2007-2008 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
+ * SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #ifndef KEDUVOCKVTML2WRITER_H
 #define KEDUVOCKVTML2WRITER_H
 
